# -*- coding: utf-8 -*-

################################################################################
## Form generated from reading UI file 'main_window_small.ui'
##
## Created by: Qt User Interface Compiler version 6.7.0
##
## WARNING! All changes made in this file will be lost when recompiling UI file!
################################################################################

from PySide6.QtCore import (QCoreApplication, QDate, QDateTime, QLocale,
    QMetaObject, QObject, QPoint, QRect,
    QSize, QTime, QUrl, Qt)
from PySide6.QtGui import (QBrush, QColor, QConicalGradient, QCursor,
    QFont, QFontDatabase, QGradient, QIcon,
    QImage, QKeySequence, QLinearGradient, QPainter,
    QPalette, QPixmap, QRadialGradient, QTransform)
from PySide6.QtWidgets import (QApplication, QCheckBox, QComboBox, QFrame,
    QHBoxLayout, QLabel, QLineEdit, QMainWindow,
    QMenuBar, QProgressBar, QPushButton, QSizePolicy,
    QSpacerItem, QStatusBar, QVBoxLayout, QWidget)

from debyetools.tpropsgui.custom_widgets import ClickableLineEdit

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        if not MainWindow.objectName():
            MainWindow.setObjectName(u"MainWindow")
        MainWindow.setWindowModality(Qt.WindowModality.WindowModal)
        MainWindow.resize(476, 466)
        self.centralwidget = QWidget(MainWindow)
        self.centralwidget.setObjectName(u"centralwidget")
        self.verticalLayout_8 = QVBoxLayout(self.centralwidget)
        self.verticalLayout_8.setObjectName(u"verticalLayout_8")
        self.horizontalLayout = QHBoxLayout()
        self.horizontalLayout.setObjectName(u"horizontalLayout")
        self.label_2 = QLabel(self.centralwidget)
        self.label_2.setObjectName(u"label_2")

        self.horizontalLayout.addWidget(self.label_2)

        self.lineEdit_11 = ClickableLineEdit(self.centralwidget)
        self.lineEdit_11.setObjectName(u"lineEdit_11")
        self.lineEdit_11.setEnabled(True)
        self.lineEdit_11.setReadOnly(True)

        self.horizontalLayout.addWidget(self.lineEdit_11)

        self.label_3 = QLabel(self.centralwidget)
        self.label_3.setObjectName(u"label_3")

        self.horizontalLayout.addWidget(self.label_3)

        self.lineEdit = QLineEdit(self.centralwidget)
        self.lineEdit.setObjectName(u"lineEdit")

        self.horizontalLayout.addWidget(self.lineEdit)

        self.label_4 = QLabel(self.centralwidget)
        self.label_4.setObjectName(u"label_4")

        self.horizontalLayout.addWidget(self.label_4)

        self.label_25 = QLabel(self.centralwidget)
        self.label_25.setObjectName(u"label_25")

        self.horizontalLayout.addWidget(self.label_25)

        self.horizontalSpacer = QSpacerItem(40, 20, QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Minimum)

        self.horizontalLayout.addItem(self.horizontalSpacer)

        self.label_24 = QLabel(self.centralwidget)
        self.label_24.setObjectName(u"label_24")

        self.horizontalLayout.addWidget(self.label_24)


        self.verticalLayout_8.addLayout(self.horizontalLayout)

        self.frame_6 = QFrame(self.centralwidget)
        self.frame_6.setObjectName(u"frame_6")
        self.frame_6.setFrameShape(QFrame.Shape.StyledPanel)
        self.frame_6.setFrameShadow(QFrame.Shadow.Raised)
        self.verticalLayout = QVBoxLayout(self.frame_6)
        self.verticalLayout.setSpacing(2)
        self.verticalLayout.setObjectName(u"verticalLayout")
        self.verticalLayout.setContentsMargins(9, 9, 9, 9)
        self.horizontalLayout_4 = QHBoxLayout()
        self.horizontalLayout_4.setObjectName(u"horizontalLayout_4")
        self.horizontalLayout_4.setContentsMargins(2, 2, 2, 2)
        self.label_7 = QLabel(self.frame_6)
        self.label_7.setObjectName(u"label_7")

        self.horizontalLayout_4.addWidget(self.label_7)

        self.lineEdit_2 = QLineEdit(self.frame_6)
        self.lineEdit_2.setObjectName(u"lineEdit_2")
        self.lineEdit_2.setMinimumSize(QSize(120, 0))

        self.horizontalLayout_4.addWidget(self.lineEdit_2)

        self.comboBox = QComboBox(self.frame_6)
        self.comboBox.addItem("")
        self.comboBox.addItem("")
        self.comboBox.addItem("")
        self.comboBox.addItem("")
        self.comboBox.addItem("")
        self.comboBox.addItem("")
        self.comboBox.addItem("")
        self.comboBox.setObjectName(u"comboBox")

        self.horizontalLayout_4.addWidget(self.comboBox)

        self.moreinfo = QLabel(self.frame_6)
        self.moreinfo.setObjectName(u"moreinfo")
        font = QFont()
        font.setPointSize(10)
        self.moreinfo.setFont(font)

        self.horizontalLayout_4.addWidget(self.moreinfo)

        self.horizontalSpacer_2 = QSpacerItem(40, 20, QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Minimum)

        self.horizontalLayout_4.addItem(self.horizontalSpacer_2)

        self.verticalLayout_2 = QVBoxLayout()
        self.verticalLayout_2.setSpacing(0)
        self.verticalLayout_2.setObjectName(u"verticalLayout_2")
        self.verticalLayout_2.setContentsMargins(0, 0, 0, 0)
        self.pushFitEOS = QPushButton(self.frame_6)
        self.pushFitEOS.setObjectName(u"pushFitEOS")
        sizePolicy = QSizePolicy(QSizePolicy.Policy.Preferred, QSizePolicy.Policy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushFitEOS.sizePolicy().hasHeightForWidth())
        self.pushFitEOS.setSizePolicy(sizePolicy)
        self.pushFitEOS.setMinimumSize(QSize(0, 25))

        self.verticalLayout_2.addWidget(self.pushFitEOS)


        self.horizontalLayout_4.addLayout(self.verticalLayout_2)


        self.verticalLayout.addLayout(self.horizontalLayout_4)


        self.verticalLayout_8.addWidget(self.frame_6)

        self.frame = QFrame(self.centralwidget)
        self.frame.setObjectName(u"frame")
        self.frame.setFrameShape(QFrame.Shape.StyledPanel)
        self.frame.setFrameShadow(QFrame.Shadow.Raised)
        self.verticalLayout_12 = QVBoxLayout(self.frame)
        self.verticalLayout_12.setSpacing(2)
        self.verticalLayout_12.setObjectName(u"verticalLayout_12")
        self.verticalLayout_12.setContentsMargins(9, 9, 9, 9)
        self.horizontalLayout_7 = QHBoxLayout()
        self.horizontalLayout_7.setObjectName(u"horizontalLayout_7")
        self.horizontalLayout_7.setContentsMargins(0, 0, 2, 0)
        self.label_16 = QLabel(self.frame)
        self.label_16.setObjectName(u"label_16")
        self.label_16.setMinimumSize(QSize(0, 22))
        self.label_16.setMaximumSize(QSize(16777215, 22))

        self.horizontalLayout_7.addWidget(self.label_16)

        self.lineEdit_3 = QLineEdit(self.frame)
        self.lineEdit_3.setObjectName(u"lineEdit_3")
        self.lineEdit_3.setMinimumSize(QSize(0, 22))
        self.lineEdit_3.setMaximumSize(QSize(16777215, 22))

        self.horizontalLayout_7.addWidget(self.lineEdit_3)

        self.horizontalSpacer_4 = QSpacerItem(40, 20, QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Minimum)

        self.horizontalLayout_7.addItem(self.horizontalSpacer_4)

        self.pushNu = QPushButton(self.frame)
        self.pushNu.setObjectName(u"pushNu")

        self.horizontalLayout_7.addWidget(self.pushNu)


        self.verticalLayout_12.addLayout(self.horizontalLayout_7)


        self.verticalLayout_8.addWidget(self.frame)

        self.frame_2 = QFrame(self.centralwidget)
        self.frame_2.setObjectName(u"frame_2")
        self.frame_2.setFrameShape(QFrame.Shape.StyledPanel)
        self.frame_2.setFrameShadow(QFrame.Shadow.Raised)
        self.horizontalLayout_8 = QHBoxLayout(self.frame_2)
        self.horizontalLayout_8.setSpacing(2)
        self.horizontalLayout_8.setObjectName(u"horizontalLayout_8")
        self.checkBox = QCheckBox(self.frame_2)
        self.checkBox.setObjectName(u"checkBox")
        self.checkBox.setChecked(True)

        self.horizontalLayout_8.addWidget(self.checkBox)

        self.lineEdit_el = QLineEdit(self.frame_2)
        self.lineEdit_el.setObjectName(u"lineEdit_el")

        self.horizontalLayout_8.addWidget(self.lineEdit_el)

        self.horizontalSpacer_3 = QSpacerItem(40, 20, QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Minimum)

        self.horizontalLayout_8.addItem(self.horizontalSpacer_3)

        self.pushDoscar = QPushButton(self.frame_2)
        self.pushDoscar.setObjectName(u"pushDoscar")

        self.horizontalLayout_8.addWidget(self.pushDoscar)


        self.verticalLayout_8.addWidget(self.frame_2)

        self.frame_3 = QFrame(self.centralwidget)
        self.frame_3.setObjectName(u"frame_3")
        self.frame_3.setFrameShape(QFrame.Shape.StyledPanel)
        self.frame_3.setFrameShadow(QFrame.Shadow.Sunken)
        self.horizontalLayout_9 = QHBoxLayout(self.frame_3)
        self.horizontalLayout_9.setSpacing(2)
        self.horizontalLayout_9.setObjectName(u"horizontalLayout_9")
        self.verticalLayout_14 = QVBoxLayout()
        self.verticalLayout_14.setObjectName(u"verticalLayout_14")
        self.checkBox_2 = QCheckBox(self.frame_3)
        self.checkBox_2.setObjectName(u"checkBox_2")
        self.checkBox_2.setMinimumSize(QSize(0, 22))
        self.checkBox_2.setMaximumSize(QSize(16777215, 22))

        self.verticalLayout_14.addWidget(self.checkBox_2)

        self.checkBox_3 = QCheckBox(self.frame_3)
        self.checkBox_3.setObjectName(u"checkBox_3")
        self.checkBox_3.setMinimumSize(QSize(0, 22))
        self.checkBox_3.setMaximumSize(QSize(16777215, 22))

        self.verticalLayout_14.addWidget(self.checkBox_3)

        self.checkBox_4 = QCheckBox(self.frame_3)
        self.checkBox_4.setObjectName(u"checkBox_4")
        self.checkBox_4.setMinimumSize(QSize(0, 22))
        self.checkBox_4.setMaximumSize(QSize(16777215, 22))

        self.verticalLayout_14.addWidget(self.checkBox_4)


        self.horizontalLayout_9.addLayout(self.verticalLayout_14)

        self.verticalLayout_15 = QVBoxLayout()
        self.verticalLayout_15.setObjectName(u"verticalLayout_15")
        self.lineEdit_def = QLineEdit(self.frame_3)
        self.lineEdit_def.setObjectName(u"lineEdit_def")
        self.lineEdit_def.setEnabled(False)
        self.lineEdit_def.setMinimumSize(QSize(0, 22))
        self.lineEdit_def.setMaximumSize(QSize(16777215, 22))
        self.lineEdit_def.setFrame(True)

        self.verticalLayout_15.addWidget(self.lineEdit_def)

        self.lineEdit_anh = QLineEdit(self.frame_3)
        self.lineEdit_anh.setObjectName(u"lineEdit_anh")
        self.lineEdit_anh.setEnabled(False)
        self.lineEdit_anh.setMinimumSize(QSize(0, 22))
        self.lineEdit_anh.setMaximumSize(QSize(16777215, 22))
        self.lineEdit_anh.setFrame(True)

        self.verticalLayout_15.addWidget(self.lineEdit_anh)

        self.lineEdit_xs = QLineEdit(self.frame_3)
        self.lineEdit_xs.setObjectName(u"lineEdit_xs")
        self.lineEdit_xs.setEnabled(False)
        self.lineEdit_xs.setMinimumSize(QSize(0, 22))
        self.lineEdit_xs.setMaximumSize(QSize(16777215, 22))
        self.lineEdit_xs.setFrame(True)

        self.verticalLayout_15.addWidget(self.lineEdit_xs)


        self.horizontalLayout_9.addLayout(self.verticalLayout_15)

        self.horizontalSpacer_5 = QSpacerItem(40, 20, QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Minimum)

        self.horizontalLayout_9.addItem(self.horizontalSpacer_5)


        self.verticalLayout_8.addWidget(self.frame_3)

        self.frame_4 = QFrame(self.centralwidget)
        self.frame_4.setObjectName(u"frame_4")
        self.frame_4.setFrameShape(QFrame.Shape.StyledPanel)
        self.frame_4.setFrameShadow(QFrame.Shadow.Raised)
        self.horizontalLayout_2 = QHBoxLayout(self.frame_4)
        self.horizontalLayout_2.setObjectName(u"horizontalLayout_2")
        self.checkBox_5 = QCheckBox(self.frame_4)
        self.checkBox_5.setObjectName(u"checkBox_5")
        self.checkBox_5.setMinimumSize(QSize(0, 22))
        self.checkBox_5.setMaximumSize(QSize(16777215, 22))

        self.horizontalLayout_2.addWidget(self.checkBox_5)

        self.verticalLayout_3 = QVBoxLayout()
        self.verticalLayout_3.setObjectName(u"verticalLayout_3")
        self.verticalLayout_3.setContentsMargins(-1, -1, -1, 0)
        self.horizontalLayout_3 = QHBoxLayout()
        self.horizontalLayout_3.setObjectName(u"horizontalLayout_3")
        self.horizontalLayout_3.setContentsMargins(-1, 0, -1, -1)
        self.lineEdit_xspol = QLineEdit(self.frame_4)
        self.lineEdit_xspol.setObjectName(u"lineEdit_xspol")
        self.lineEdit_xspol.setEnabled(False)
        self.lineEdit_xspol.setMinimumSize(QSize(0, 22))
        self.lineEdit_xspol.setMaximumSize(QSize(16777215, 22))
        self.lineEdit_xspol.setFrame(True)

        self.horizontalLayout_3.addWidget(self.lineEdit_xspol)

        self.horizontalSpacer_7 = QSpacerItem(40, 20, QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Minimum)

        self.horizontalLayout_3.addItem(self.horizontalSpacer_7)


        self.verticalLayout_3.addLayout(self.horizontalLayout_3)


        self.horizontalLayout_2.addLayout(self.verticalLayout_3)


        self.verticalLayout_8.addWidget(self.frame_4)

        self.horizontalLayout_10 = QHBoxLayout()
        self.horizontalLayout_10.setObjectName(u"horizontalLayout_10")
        self.horizontalSpacer_6 = QSpacerItem(40, 20, QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Minimum)

        self.horizontalLayout_10.addItem(self.horizontalSpacer_6)

        self.verticalLayout_TP = QVBoxLayout()
        self.verticalLayout_TP.setSpacing(0)
        self.verticalLayout_TP.setObjectName(u"verticalLayout_TP")
        self.verticalLayout_TP.setContentsMargins(0, -1, -1, -1)
        self.verticalSpacer_9 = QSpacerItem(20, 40, QSizePolicy.Policy.Minimum, QSizePolicy.Policy.Expanding)

        self.verticalLayout_TP.addItem(self.verticalSpacer_9)

        self.horizontalLayout_T = QHBoxLayout()
        self.horizontalLayout_T.setSpacing(0)
        self.horizontalLayout_T.setObjectName(u"horizontalLayout_T")
        self.horizontalLayout_T.setContentsMargins(0, -1, -1, -1)
        self.label_T = QLabel(self.centralwidget)
        self.label_T.setObjectName(u"label_T")

        self.horizontalLayout_T.addWidget(self.label_T)

        self.lineEdit_T = QLineEdit(self.centralwidget)
        self.lineEdit_T.setObjectName(u"lineEdit_T")

        self.horizontalLayout_T.addWidget(self.lineEdit_T)

        self.label_T_2 = QLabel(self.centralwidget)
        self.label_T_2.setObjectName(u"label_T_2")
        self.label_T_2.setMinimumSize(QSize(20, 0))
        self.label_T_2.setMaximumSize(QSize(50, 16777215))

        self.horizontalLayout_T.addWidget(self.label_T_2)


        self.verticalLayout_TP.addLayout(self.horizontalLayout_T)

        self.horizontalLayout_P = QHBoxLayout()
        self.horizontalLayout_P.setSpacing(0)
        self.horizontalLayout_P.setObjectName(u"horizontalLayout_P")
        self.horizontalLayout_P.setContentsMargins(0, -1, -1, -1)
        self.label_P = QLabel(self.centralwidget)
        self.label_P.setObjectName(u"label_P")

        self.horizontalLayout_P.addWidget(self.label_P)

        self.lineEdit_P = QLineEdit(self.centralwidget)
        self.lineEdit_P.setObjectName(u"lineEdit_P")

        self.horizontalLayout_P.addWidget(self.lineEdit_P)

        self.label_P_2 = QLabel(self.centralwidget)
        self.label_P_2.setObjectName(u"label_P_2")
        self.label_P_2.setMinimumSize(QSize(20, 0))
        self.label_P_2.setMaximumSize(QSize(50, 16777215))

        self.horizontalLayout_P.addWidget(self.label_P_2)


        self.verticalLayout_TP.addLayout(self.horizontalLayout_P)


        self.horizontalLayout_10.addLayout(self.verticalLayout_TP)

        self.verticalLayout_17 = QVBoxLayout()
        self.verticalLayout_17.setSpacing(2)
        self.verticalLayout_17.setObjectName(u"verticalLayout_17")
        self.verticalLayout_17.setContentsMargins(0, 0, 0, 0)
        self.verticalSpacer_8 = QSpacerItem(20, 40, QSizePolicy.Policy.Minimum, QSizePolicy.Policy.Expanding)

        self.verticalLayout_17.addItem(self.verticalSpacer_8)

        self.pushgoback = QPushButton(self.centralwidget)
        self.pushgoback.setObjectName(u"pushgoback")
        self.pushgoback.setEnabled(True)

        self.verticalLayout_17.addWidget(self.pushgoback)

        self.progress_3 = QProgressBar(self.centralwidget)
        self.progress_3.setObjectName(u"progress_3")
        self.progress_3.setMaximumSize(QSize(16777215, 2))
        self.progress_3.setValue(0)
        self.progress_3.setTextVisible(False)
        self.progress_3.setInvertedAppearance(False)

        self.verticalLayout_17.addWidget(self.progress_3)


        self.horizontalLayout_10.addLayout(self.verticalLayout_17)

        self.verticalLayout_16 = QVBoxLayout()
        self.verticalLayout_16.setSpacing(2)
        self.verticalLayout_16.setObjectName(u"verticalLayout_16")
        self.verticalSpacer_7 = QSpacerItem(20, 40, QSizePolicy.Policy.Minimum, QSizePolicy.Policy.Expanding)

        self.verticalLayout_16.addItem(self.verticalSpacer_7)

        self.pushButton_5 = QPushButton(self.centralwidget)
        self.pushButton_5.setObjectName(u"pushButton_5")
        self.pushButton_5.setEnabled(True)

        self.verticalLayout_16.addWidget(self.pushButton_5)

        self.progress = QProgressBar(self.centralwidget)
        self.progress.setObjectName(u"progress")
        self.progress.setMaximumSize(QSize(16777215, 2))
        self.progress.setValue(0)
        self.progress.setTextVisible(False)
        self.progress.setInvertedAppearance(False)

        self.verticalLayout_16.addWidget(self.progress)


        self.horizontalLayout_10.addLayout(self.verticalLayout_16)


        self.verticalLayout_8.addLayout(self.horizontalLayout_10)

        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QMenuBar(MainWindow)
        self.menubar.setObjectName(u"menubar")
        self.menubar.setGeometry(QRect(0, 0, 476, 21))
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QStatusBar(MainWindow)
        self.statusbar.setObjectName(u"statusbar")
        MainWindow.setStatusBar(self.statusbar)

        self.retranslateUi(MainWindow)

        QMetaObject.connectSlotsByName(MainWindow)
    # setupUi

    def retranslateUi(self, MainWindow):
        MainWindow.setWindowTitle(QCoreApplication.translate("MainWindow", u"debyetools - [input parameters]", None))
        self.label_2.setText(QCoreApplication.translate("MainWindow", u"formula:", None))
        self.lineEdit_11.setText("")
        self.label_3.setText(QCoreApplication.translate("MainWindow", u"mass:", None))
        self.lineEdit.setText("")
        self.label_4.setText(QCoreApplication.translate("MainWindow", u"kg/mol-at", None))
        self.label_25.setText("")
        self.label_24.setText("")
        self.label_7.setText(QCoreApplication.translate("MainWindow", u"EOS params:", None))
        self.lineEdit_2.setText(QCoreApplication.translate("MainWindow", u"-3e5, 1e-5, 7e10, 4", None))
        self.comboBox.setItemText(0, QCoreApplication.translate("MainWindow", u"Birch-Murnaghan", None))
        self.comboBox.setItemText(1, QCoreApplication.translate("MainWindow", u"Rose-Vinet", None))
        self.comboBox.setItemText(2, QCoreApplication.translate("MainWindow", u"Mie-Gruneisen", None))
        self.comboBox.setItemText(3, QCoreApplication.translate("MainWindow", u"TB-SMA", None))
        self.comboBox.setItemText(4, QCoreApplication.translate("MainWindow", u"Murnaghan", None))
        self.comboBox.setItemText(5, QCoreApplication.translate("MainWindow", u"Poirier-Tarantola", None))
        self.comboBox.setItemText(6, QCoreApplication.translate("MainWindow", u"Morse potential", None))

        self.moreinfo.setText(QCoreApplication.translate("MainWindow", u"\u24d8", None))
        self.pushFitEOS.setText(QCoreApplication.translate("MainWindow", u"fit parameters", None))
        self.label_16.setText(QCoreApplication.translate("MainWindow", u"Poisson's ratio:", None))
        self.lineEdit_3.setText(QCoreApplication.translate("MainWindow", u"0.25", None))
        self.pushNu.setText(QCoreApplication.translate("MainWindow", u"calculate Poisson's ratio", None))
        self.checkBox.setText(QCoreApplication.translate("MainWindow", u"electronic contribution:", None))
        self.lineEdit_el.setText(QCoreApplication.translate("MainWindow", u"0, 0, 0, 0", None))
        self.pushDoscar.setText(QCoreApplication.translate("MainWindow", u"calculate parameters", None))
        self.checkBox_2.setText(QCoreApplication.translate("MainWindow", u"mono-vacancies:", None))
        self.checkBox_3.setText(QCoreApplication.translate("MainWindow", u"intrinsic anh.:", None))
        self.checkBox_4.setText(QCoreApplication.translate("MainWindow", u"explicit anh.:", None))
        self.lineEdit_def.setText(QCoreApplication.translate("MainWindow", u"100, 1, 1000, 0.1", None))
        self.lineEdit_anh.setText(QCoreApplication.translate("MainWindow", u"0, 1", None))
        self.lineEdit_xs.setText(QCoreApplication.translate("MainWindow", u"0, 0, 0", None))
        self.checkBox_5.setText(QCoreApplication.translate("MainWindow", u"excess polynomial", None))
        self.lineEdit_xspol.setText(QCoreApplication.translate("MainWindow", u"0,0,0,0", None))
        self.label_T.setText(QCoreApplication.translate("MainWindow", u"T:", None))
        self.lineEdit_T.setText(QCoreApplication.translate("MainWindow", u"0.1 1000 50", None))
        self.label_T_2.setText(QCoreApplication.translate("MainWindow", u"K", None))
        self.label_P.setText(QCoreApplication.translate("MainWindow", u"P:", None))
        self.lineEdit_P.setText(QCoreApplication.translate("MainWindow", u"0 30 10", None))
        self.label_P_2.setText(QCoreApplication.translate("MainWindow", u"GPa", None))
        self.pushgoback.setText(QCoreApplication.translate("MainWindow", u"< go back", None))
        self.pushButton_5.setText(QCoreApplication.translate("MainWindow", u"run >", None))
    # retranslateUi




# This Python file uses the following encoding: utf-8
import sys

from PySide6.QtWidgets import QApplication, QMainWindow

from debyetools.tpropsgui.dialog_periodictable import dialogPeriodicTable
from debyetools.tpropsgui.dialog_crystal import dialogCrystal
# from main_window import dialogMainWindow
from debyetools.tpropsgui.main_window_small import dialogMainWindow

from debyetools.tpropsgui.atomtools import Molecule
from PySide6.QtCore import Qt, QTimer
# Important:
# You need to run the following command to generate the ui_form.py file
#     pyside6-uic form.ui -o ui_form.py, or
#     pyside2-uic form.ui -o ui_form.py
from debyetools.tpropsgui.ui_start_window import Ui_StartWindow
from PySide6.QtGui import QPixmap, QPalette

def highlight_line_edit(line_edit, color="purple", duration=100):
    # Set the background color
    line_edit.setStyleSheet(f"background-color: {color};")

    # Create a QTimer to reset the color after `duration` milliseconds
    timer = QTimer(line_edit)
    timer.setSingleShot(True)  # Only trigger once
    timer.timeout.connect(lambda: line_edit.setStyleSheet(""))  # Reset the color
    timer.start(duration)


class StartWindow(QMainWindow):
    def __init__(self, parent=None):
        super().__init__(parent)
        self.ui = Ui_StartWindow()
        self.ui.setupUi(self)

        self.dialogperiodictable = dialogPeriodicTable(self)
        self.ui.lineEdit_compoundname.clicked.connect(self.showDialogPeriodicTable)
        self.dialogperiodictable.external_lineEdit = self.ui.lineEdit_compoundname
        self.dialogperiodictable.external_lineEdit2 = self.ui.lineEdit_mass

        self.ui.pushButtonNext.clicked.connect(self.showDialogNext)

        self.dialogmainwindow = dialogMainWindow(self)
        self.dialogcrystal = dialogCrystal(self)

        self.molecule = Molecule()
        self.removed_items = {}

        # Connect the textChanged signals to a shared color change method
        self.ui.lineEdit_compoundname.textChanged.connect(lambda: self.on_text_changed(self.ui.lineEdit_compoundname))
        self.ui.lineEdit_mass.textChanged.connect(lambda: self.on_text_changed(self.ui.lineEdit_mass))
        self.ui.lineEdit_2.textChanged.connect(lambda: self.on_text_changed(self.ui.lineEdit_2))



    def showDialogPeriodicTable(self):
        self.dialogperiodictable.ui.lineEdit.setText(self.ui.lineEdit_compoundname.text())
        self.dialogperiodictable.show()  # Assuming dialogxx is initialized and ready to be displayed

    def showDialogNext(self):
        self.dialogmainwindow.app=self.app
        if self.ui.checkBox.isChecked():

            self.dialogcrystal.molecule = self.molecule
            self.dialogcrystal.eos_str = 'MP'

            self.dialogcrystal.dialogmainwindow = self.dialogmainwindow

            self.dialogcrystal.copied_mass = self.ui.lineEdit_mass.text()
            self.dialogcrystal.copied_name = self.ui.lineEdit_compoundname.text()

            self.show_hidden_comboboxitems()
            self.removed_items = {i:self.dialogmainwindow.ui.comboBox.itemText(i) for i in range(6)}
            print('removed_items', self.removed_items)
            for i in range(self.dialogmainwindow.ui.comboBox.count()-1, -1, -1):
                print(self.dialogmainwindow.ui.comboBox.itemText(i))
                if self.dialogmainwindow.ui.comboBox.itemText(i) in self.removed_items.values():
                    print(i, self.dialogmainwindow.ui.comboBox.itemText(i))

                    self.dialogmainwindow.ui.comboBox.removeItem(i)


            self.dialogcrystal.show()
        else:
            self.dialogmainwindow.ui.lineEdit.setText(self.ui.lineEdit_mass.text())
            self.dialogmainwindow.ui.lineEdit_11.setText(self.ui.lineEdit_compoundname.text())

            self.show_hidden_comboboxitems()
            self.removed_items = { 6: self.dialogmainwindow.ui.comboBox.itemText(6)}
            self.dialogmainwindow.ui.comboBox.removeItem(6)
            self.dialogmainwindow.show()


    def show_hidden_comboboxitems(self):
            for ix,value in self.removed_items.items():

                self.dialogmainwindow.ui.comboBox.insertItem(ix,value)

    def is_dark_mode(self):
        # Detect if the application is in dark mode using the palette
        palette = self.palette()
        return palette.color(QPalette.ColorRole.Window).value() < 128  # Lightness threshold for dark mode

    def on_text_changed(self, line_edit):
        # Call the reusable highlight function
        dark_mode = self.is_dark_mode()
        color_p = "purple" if dark_mode else "#94a2c9"

        highlight_line_edit(line_edit, color=color_p, duration=500)
        # Update label with the current content of the edited line edit








from debyetools.tpropsgui.elastic_props import run_script
from debyetools.aux_functions import load_EM

EM = load_EM( '../Al3Li_L12/OUTCAR_elastic')/10
txt2output, results_data = run_script(EM)

print(txt2output.expandtabs(8))



from PySide6.QtWidgets import QDialog
from debyetools.tpropsgui.ui_dialog_elastic import Ui_Dialog as Ui_elastic
from debyetools.tpropsgui.dialog_plots_elastic import dialogPlots
import debyetools.tpropsgui.elastic_props as elastic
import numpy as np
class dialogElastic(QDialog):
    def __init__(self, parent=None):
        super().__init__(parent)
        self.ui = Ui_elastic()
        self.ui.setupUi(self)

        self.ui.pushButton.clicked.connect(self.on_pushPlots)

        self.dialog_plots = dialogPlots(self)





    def on_pushPlots(self):
        # print('ssss')
        self.dialog_plots.ax1, self.dialog_plots.ax2, self.dialog_plots.ax3, self.dialog_plots.ax4 = elastic.run_script_plots([self.dialog_plots.ax1, self.dialog_plots.ax2, self.dialog_plots.ax3, self.dialog_plots.ax4], self.EM)

        # self.dialog_plots.ax1[0].plot([0,1],[0,1])

        self.dialog_plots.fig1.subplots_adjust(wspace=0.8)
        self.dialog_plots.fig2.subplots_adjust(wspace=0.8)
        self.dialog_plots.fig3.subplots_adjust(wspace=0.8)
        self.dialog_plots.fig4.subplots_adjust(wspace=0.8)

        planestr = ['xy', 'xz', 'yz']
        for i, axi in enumerate(self.dialog_plots.ax1):
            axi.text(5/4*np.pi, axi.get_rmax()*2.1, f'{planestr[i]} plane', fontsize=8, ha='center')
        for i, axi in enumerate(self.dialog_plots.ax2):
            axi.text(5/4*np.pi, axi.get_rmax()*2, f'{planestr[i]} plane', fontsize=8, ha='center')
        for i, axi in enumerate(self.dialog_plots.ax3):
            axi.text(5/4*np.pi, axi.get_rmax()*2, f'{planestr[i]} plane', fontsize=8, ha='center')
        for i, axi in enumerate(self.dialog_plots.ax4):
            axi.text(5/4*np.pi, axi.get_rmax()*2, f'{planestr[i]} plane', fontsize=8, ha='center')

        self.dialog_plots.show()



# Always prefer setuptools over distutils
from setuptools import setup, find_packages

# To use a consistent encoding
from codecs import open
from os import path

# The directory containing this file
HERE = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(HERE, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

# This call to setup() does all the work
setup(
    name="debyetools",
    version="2.8.1",
    description="Debye approximation implementation for the calculation of thermodynamic properties from ground-state atomistic simulations.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://debyetools.readthedocs.io/",
    author="Javier Jofre",
    author_email="javier.jofre@polymtl.ca",
    license="GPLv3",
    classifiers=[
        "Intended Audience :: Developers",
        "License :: OSI Approved :: GNU Affero General Public License v3",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.12",
        "Operating System :: OS Independent"
    ],
    packages=["debyetools", "debyetools.tpropsgui", "debyetools.examples"],
    include_package_data=True,
    install_requires=["numpy", "scipy", "matplotlib", "mpmath", "PySide6", "deap"],
    package_data={
    'debyetools': ['examples/*', 'examples/*/*'],
},
)



import os
import numpy as np
import re
from scipy.optimize import curve_fit

# Function to parse energy and volume from OUTCAR
def parse_outcar(outcar_path):
    with open(outcar_path, 'r') as file:
        lines = file.readlines()

    energy = None
    volume = None

    # Find the last occurrence of energy and volume in the OUTCAR
    for line in lines[::-1]:
        if "FREE ENERGIE OF THE ION-ELECTRON SYSTEM" in line:
            energy = float(re.findall(r"[-+]?\d*\.\d+|\d+", lines[lines.index(line)+2])[0])
        if "volume of cell :" in line:
            volume = float(line.split()[-1])

    return energy, volume

# Quadratic function for fitting
def quadratic_fun(delta, eps, E0, V0):
    return E0 + V0/2 * eps * delta**2

def get_EM(base_dir):

    # Base directory containing d1 to d6 folders
    # base_dir = './elastic/'

    # Prepare a list to store the epsilon values
    epsilons = []

    # Loop over each d* folder
    for d in range(1, 10):
        d_folder = os.path.join(base_dir, f'eps{d}')

        strains = []
        energies = []

        # Loop over subfolders '98' to '102'
        for delta_folder in ['98', '99', '100', '101', '102']:
            sub_folder = os.path.join(d_folder, delta_folder)
            outcar_path = os.path.join(sub_folder, 'OUTCAR')

            # Parse energy and volume from OUTCAR
            energy, volume = parse_outcar(outcar_path)

            # For the '100' subfolder, get E0 and V0
            if delta_folder == '100':
                E0 = energy
                V0 = volume

            # Calculate strain (delta) from folder name
            delta = (int(delta_folder) - 100) / 100.0
            strains.append(delta)
            energies.append(energy)

        # Convert to numpy arrays for fitting
        strains = np.array(strains)
        energies = np.array(energies)

        # Fit the quadratic function to the energy vs. strain data
        quadratic = lambda delta, eps: quadratic_fun(delta, eps, E0, V0)
        popt, _ = curve_fit(quadratic, strains, energies)

        # Extract the epsilon (eps) for this deformation
        epsilon = popt[0]
        epsilons.append(epsilon)

    # Now solve the system of equations using the epsilons to get the Cij constants
    C11 = epsilons[0]
    C22 = epsilons[1]
    C33 = epsilons[2]
    C44 = epsilons[3]/4
    C55 = epsilons[4]/4
    C66 = epsilons[5]/4
    C12 = (epsilons[0]+epsilons[1]-epsilons[6])/2
    C13 = (epsilons[0]+epsilons[2]-epsilons[7])/2
    C23 = (epsilons[1]+epsilons[2]-epsilons[8])/2
    # Store the calculated elastic constants
    EM =np.zeros((6,6))
    elastic_constants = {
        'C11': C11*160.21766208,
        'C12': C12*160.21766208,
        'C13': C13*160.21766208,
        'C14': 0,
        'C15': 0,
        'C16': 0,
        'C21': C12*160.21766208,
        'C22': C22*160.21766208,
        'C23': C23*160.21766208,
        'C24': 0,
        'C25': 0,
        'C26': 0,
        'C31': C13*160.21766208,
        'C32': C23*160.21766208,
        'C33': C33*160.21766208,
        'C34': 0,
        'C35': 0,
        'C36': 0,
        'C41': 0,
        'C42': 0,
        'C43': 0,
        'C44': C44*160.21766208,
        'C45': 0,
        'C46': 0,
        'C51': 0,
        'C52': 0,
        'C53': 0,
        'C54': 0,
        'C55': C55*160.21766208,
        'C56': 0,
        'C61': 0,
        'C62': 0,
        'C63': 0,
        'C64': 0,
        'C65': 0,
        'C66': C66*160.21766208,

    }

    for i in range(0,6):
        for j in range(0,6):
            EM[i,j] = elastic_constants[f'C{i+1}{j+1}']
    return EM



from deap import base, creator, tools, algorithms
import numpy as np
import random
from debyetools.ndeb import nDeb


def get_params_list(params, params_alt, lst_str_alt):
    # E0, V0, K0, K0p, nu, a0, m0, s0, s1, s2, edef, sdef, vdef, pel0, pel1, pel2, pel3
    lst_str = ['E0', 'V0', 'K0', 'K0p', 'nu', 'a0', 'm0', 's0', 's1', 's2',
               'edef', 'sdef', 'vdef', 'pel0', 'pel1', 'pel2', 'pel3', 'xs0', 'xs1', 'xs2', 'xs3', 'xs4', 'xs5']

    dict_params = dict(zip(lst_str, params))
    dict_params_alt = dict(zip(lst_str_alt, params_alt))
    lst_params = []
    for k in lst_str:
        if k in lst_str_alt:
            lst_params.append(dict_params_alt[k])
        else:
            lst_params.append(dict_params[k])

    return lst_params


def eval_distance(sample, min_distance, mean_distance):
    sorted_sample = np.sort(sample)
    differences = np.diff(sorted_sample)

    if np.mean(differences) <= mean_distance:
        return False
    else:
        if np.min(differences) <= min_distance:
            return False
        else:
            return True


def random_sample_with_min_distance_2d(array, sample_size, min_distance, mean_distance, rec_depth=0):
    # Extract the second row which will be used for comparison
    values_to_sample_from = array[1, :]

    indexes = array[0, :]

    sample = random.sample(list(values_to_sample_from), sample_size)
    index_sample = [np.where(array[1, :] == i)[0][0] for i in sample]
    sorted_ix = np.argsort(sample)
    sample = np.array(sample)[sorted_ix]
    index_sample = np.array(index_sample)[sorted_ix]

    eval_dist = eval_distance(sample, min_distance, mean_distance)

    if eval_dist or rec_depth > 500:

        return np.array([indexes[index_sample], sample])

    else:
        return random_sample_with_min_distance_2d(array, sample_size, min_distance, mean_distance, rec_depth + 1)

def props(T, params, mass,  eos_pot, Tmelting, v=False):
    global time_eos, time_Fmin, time_tprops
    E0, V0, K0, K0p, nu, a0, m0, s0, s1, s2, edef, sdef, vdef, pel0, pel1, pel2, pel3, xs0, xs1, xs2, xs3, xs4, xs5 = params

    # print('params:', params)
    p_intanh = np.array([a0, m0])
    p_anh =  np.array([s0, s1, s2])
    p_electronic = np.array([pel0, pel1, pel2, pel3])
    p_defects = np.array([edef, np.sqrt(sdef ** 2), Tmelting, vdef])
    # print('p_defects', p_defects)

    # EOS parametrization
    #=========================
    initial_parameters = [E0, V0, K0, K0p]
    eos_pot.fitEOS([V0], 0, initial_parameters=initial_parameters, fit=False)
    p_EOS = eos_pot.pEOS
    #=========================

    # F minimization
    #=========================
    ndeb_MU = nDeb(nu, mass, p_intanh, eos_pot, p_electronic, p_defects, p_anh, mode='jjsl',
                   xsparams=[xs0, xs1, xs2, xs3, xs4, xs5], r=1)
    # ndeb_MU.r = 4
    T, V = ndeb_MU.min_G(T, p_EOS[1], P=0)
    # print(f'T: [{T[0]:.2f} ... {T[-1]:.2f}]')
    # print(f'V: [{V[0]:.2e} ... {V[-1]:.2e}]')
    #=========================

    # Evaluations
    #=========================
    tprops_dict = ndeb_MU.eval_props(T, V, P=0)

    #=========================
    del V
    return tprops_dict

# Fitness function
# def eval_error(f, pf, Xdata, Ydata, norm_factor):
#     pfdenorm = [pfi*nfi for nfi, pfi in zip(norm_factor, pf)]
#     Ymodel = f(Xdata, pfdenorm)
#     return np.sqrt(np.mean(((Ydata - Ymodel)/Xdata)**2)),


def bounded_mutate(individual, low, up, indpb):
    size = len(individual)
    for i in range(size):
        if random.random() < indpb:
            individual[i] += random.gauss(0, 1)
            if individual[i] < low:
                individual[i] = low
            elif individual[i] > up:
                individual[i] = up
    return individual,


import random
import numpy as np


# Step 1: Define fitness function
def eval_error(f, individual, Xdata, Ydata, norm_factor):
    # Denormalize parameters
    denorm_individual = [param * factor for param, factor in zip(individual, norm_factor)]
    # Calculate the error as fitness (e.g., mean squared error between predicted and actual Y)
    predictions = f(Xdata, denorm_individual)
    mse = np.mean((Ydata - predictions) ** 2)
    return mse


# Step 2: Initialize population
def initialize_population(npop, n_params, plimdn, plimup):
    population = [[random.uniform(plimdn, plimup) for _ in range(n_params)] for _ in range(npop)]
    return population


# Step 3: Selection (Tournament Selection)
def tournament_selection(population, fitnesses, tournsize=3):
    selected = []
    for _ in range(len(population)):
        tournament = random.sample(list(zip(population, fitnesses)), tournsize)
        selected.append(min(tournament, key=lambda x: x[1])[0])  # Minimize fitness
    return selected


# Step 4: Crossover (Blend Crossover)
def blend_crossover(parent1, parent2, alpha=0.5):
    return [(alpha * p1 + (1 - alpha) * p2) for p1, p2 in zip(parent1, parent2)]


# Step 5: Mutation (Bounded Mutation)
def bounded_mutate(individual, low, up, pmut):
    return [random.uniform(low, up) if random.random() < pmut else gene for gene in individual]


# Step 6: Genetic Algorithm Main Function
def ga_fitting(f, Xdata, Ydata, initial_guess, param_range=(0.8, 1.2), npop=20, ngen=100, tol=1e-6,
               pcross=0.5, pmut=0.2, stagnant_gens=20, verbose=True):
    norm_factor = initial_guess
    plimdn, plimup = param_range
    n_params = len(initial_guess)

    # Initialize population
    population = initialize_population(npop, n_params, plimdn, plimup)

    prev_best = None
    stagnant_count = 0

    best_individual = [1 for _ in range(n_params)]
    if verbose:
        print('Initial fitness:', eval_error(f, best_individual, Xdata, Ydata, norm_factor))

    for gen in range(ngen):
        # Step 1: Evaluate fitness
        population = population + [best_individual]
        fitnesses = [eval_error(f, ind, Xdata, Ydata, norm_factor) for ind in population]

        # Step 2: Check for convergence
        best_fitness = min(fitnesses)
        best_individual = population[fitnesses.index(best_fitness)]
        best_individual_denorm = [p * f for p, f in zip(best_individual, norm_factor)]
        norm_factor = best_individual_denorm

        if verbose:
            print(
                f"Generation {gen}: Best fitness = {best_fitness}, stagnant count: {stagnant_count}")

        if prev_best is not None:
            if abs(best_fitness - prev_best) < tol:

                stagnant_count += 1
            elif abs(best_fitness - prev_best) < tol/10:
                stagnant_count = stagnant_gens
            else:
                stagnant_count = 0
        prev_best = best_fitness

        if stagnant_count >= stagnant_gens:
            if verbose:
                print("Convergence criterion met. Stopping.")
            break

        # Step 3: Selection
        selected = tournament_selection(population, fitnesses)

        # Step 4: Crossover and Mutation
        offspring = []
        while len(offspring) < npop:
            if random.random() < pcross:
                # Perform crossover
                parent1, parent2 = random.sample(selected, 2)
                child = blend_crossover(parent1, parent2)
            else:
                # No crossover, just copy
                child = random.choice(selected)

            # Perform mutation
            child = bounded_mutate(child, plimdn, plimup, pmut)
            offspring.append(child)

        # Replace population with offspring
        population = offspring



    # Return denormalized best individual
    print("Best individual:", best_individual_denorm)
    print("Best fitness:", best_fitness)

    return best_individual_denorm



# -*- coding: utf-8 -*-

################################################################################
## Form generated from reading UI file 'dialog_fitEOS.ui'
##
## Created by: Qt User Interface Compiler version 6.7.0
##
## WARNING! All changes made in this file will be lost when recompiling UI file!
################################################################################

from PySide6.QtCore import (QCoreApplication, QDate, QDateTime, QLocale,
    QMetaObject, QObject, QPoint, QRect,
    QSize, QTime, QUrl, Qt)
from PySide6.QtGui import (QBrush, QColor, QConicalGradient, QCursor,
    QFont, QFontDatabase, QGradient, QIcon,
    QImage, QKeySequence, QLinearGradient, QPainter,
    QPalette, QPixmap, QRadialGradient, QTransform)
from PySide6.QtWidgets import (QApplication, QComboBox, QFrame, QHBoxLayout,
    QLabel, QLineEdit, QPlainTextEdit, QProgressBar,
    QPushButton, QRadioButton, QSizePolicy, QSpacerItem,
    QVBoxLayout, QWidget)

class Ui_Form(object):
    def setupUi(self, Form):
        if not Form.objectName():
            Form.setObjectName(u"Form")
        Form.setWindowModality(Qt.WindowModality.WindowModal)
        Form.resize(427, 227)
        self.verticalLayout_5 = QVBoxLayout(Form)
        self.verticalLayout_5.setObjectName(u"verticalLayout_5")
        self.frame_6 = QFrame(Form)
        self.frame_6.setObjectName(u"frame_6")
        self.frame_6.setFrameShape(QFrame.Shape.Box)
        self.frame_6.setFrameShadow(QFrame.Shadow.Raised)
        self.verticalLayout_3 = QVBoxLayout(self.frame_6)
        self.verticalLayout_3.setSpacing(2)
        self.verticalLayout_3.setObjectName(u"verticalLayout_3")
        self.verticalLayout_3.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_3 = QHBoxLayout()
        self.horizontalLayout_3.setObjectName(u"horizontalLayout_3")
        self.horizontalLayout_3.setContentsMargins(2, 2, 2, 2)
        self.label_3 = QLabel(self.frame_6)
        self.label_3.setObjectName(u"label_3")
        self.label_3.setMaximumSize(QSize(50, 16777215))

        self.horizontalLayout_3.addWidget(self.label_3)

        self.EvVText_2 = QPlainTextEdit(self.frame_6)
        self.EvVText_2.setObjectName(u"EvVText_2")
        sizePolicy = QSizePolicy(QSizePolicy.Policy.Preferred, QSizePolicy.Policy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.EvVText_2.sizePolicy().hasHeightForWidth())
        self.EvVText_2.setSizePolicy(sizePolicy)
        self.EvVText_2.setMinimumSize(QSize(0, 100))

        self.horizontalLayout_3.addWidget(self.EvVText_2)

        self.verticalLayout = QVBoxLayout()
        self.verticalLayout.setSpacing(2)
        self.verticalLayout.setObjectName(u"verticalLayout")
        self.verticalLayout.setContentsMargins(2, 2, 2, 2)
        self.frame_7 = QFrame(self.frame_6)
        self.frame_7.setObjectName(u"frame_7")
        sizePolicy1 = QSizePolicy(QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Expanding)
        sizePolicy1.setHorizontalStretch(0)
        sizePolicy1.setVerticalStretch(0)
        sizePolicy1.setHeightForWidth(self.frame_7.sizePolicy().hasHeightForWidth())
        self.frame_7.setSizePolicy(sizePolicy1)
        self.frame_7.setMinimumSize(QSize(160, 100))
        self.frame_7.setFrameShape(QFrame.Shape.NoFrame)
        self.frame_7.setFrameShadow(QFrame.Shadow.Plain)
        self.radioButton_2 = QRadioButton(self.frame_7)
        self.radioButton_2.setObjectName(u"radioButton_2")
        self.radioButton_2.setEnabled(True)
        self.radioButton_2.setGeometry(QRect(10, 20, 151, 22))
        sizePolicy1.setHeightForWidth(self.radioButton_2.sizePolicy().hasHeightForWidth())
        self.radioButton_2.setSizePolicy(sizePolicy1)
        self.radioButton_2.setChecked(True)
        self.radioButton_4 = QRadioButton(self.frame_7)
        self.radioButton_4.setObjectName(u"radioButton_4")
        self.radioButton_4.setEnabled(True)
        self.radioButton_4.setGeometry(QRect(10, 40, 151, 22))
        self.radioButton_4.setMinimumSize(QSize(100, 0))
        self.radioButton_4.setChecked(False)
        self.label_7 = QLabel(self.frame_7)
        self.label_7.setObjectName(u"label_7")
        self.label_7.setGeometry(QRect(10, 0, 31, 16))

        self.verticalLayout.addWidget(self.frame_7)

        self.verticalSpacer = QSpacerItem(20, 40, QSizePolicy.Policy.Minimum, QSizePolicy.Policy.Expanding)

        self.verticalLayout.addItem(self.verticalSpacer)

        self.horizontalLayout_2 = QHBoxLayout()
        self.horizontalLayout_2.setSpacing(0)
        self.horizontalLayout_2.setObjectName(u"horizontalLayout_2")
        self.pushloadEvV = QPushButton(self.frame_6)
        self.pushloadEvV.setObjectName(u"pushloadEvV")

        self.horizontalLayout_2.addWidget(self.pushloadEvV)

        self.horizontalSpacer_2 = QSpacerItem(40, 20, QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Minimum)

        self.horizontalLayout_2.addItem(self.horizontalSpacer_2)


        self.verticalLayout.addLayout(self.horizontalLayout_2)


        self.horizontalLayout_3.addLayout(self.verticalLayout)


        self.verticalLayout_3.addLayout(self.horizontalLayout_3)

        self.horizontalLayout_5 = QHBoxLayout()
        self.horizontalLayout_5.setObjectName(u"horizontalLayout_5")
        self.horizontalLayout_5.setContentsMargins(2, 2, 2, 2)
        self.horizontalSpacer_5 = QSpacerItem(40, 20, QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Minimum)

        self.horizontalLayout_5.addItem(self.horizontalSpacer_5)

        self.label_8 = QLabel(self.frame_6)
        self.label_8.setObjectName(u"label_8")

        self.horizontalLayout_5.addWidget(self.label_8)

        self.lineEdit_3 = QLineEdit(self.frame_6)
        self.lineEdit_3.setObjectName(u"lineEdit_3")
        self.lineEdit_3.setMinimumSize(QSize(100, 0))

        self.horizontalLayout_5.addWidget(self.lineEdit_3)

        self.verticalLayout_4 = QVBoxLayout()
        self.verticalLayout_4.setSpacing(0)
        self.verticalLayout_4.setObjectName(u"verticalLayout_4")
        self.verticalLayout_4.setContentsMargins(0, 0, 0, 0)
        self.pushButton_2 = QPushButton(self.frame_6)
        self.pushButton_2.setObjectName(u"pushButton_2")
        sizePolicy2 = QSizePolicy(QSizePolicy.Policy.Preferred, QSizePolicy.Policy.Preferred)
        sizePolicy2.setHorizontalStretch(0)
        sizePolicy2.setVerticalStretch(0)
        sizePolicy2.setHeightForWidth(self.pushButton_2.sizePolicy().hasHeightForWidth())
        self.pushButton_2.setSizePolicy(sizePolicy2)
        self.pushButton_2.setMinimumSize(QSize(0, 25))

        self.verticalLayout_4.addWidget(self.pushButton_2)

        self.progress_3 = QProgressBar(self.frame_6)
        self.progress_3.setObjectName(u"progress_3")
        self.progress_3.setMaximumSize(QSize(16777215, 2))
        self.progress_3.setValue(0)
        self.progress_3.setTextVisible(False)
        self.progress_3.setInvertedAppearance(False)

        self.verticalLayout_4.addWidget(self.progress_3)


        self.horizontalLayout_5.addLayout(self.verticalLayout_4)

        self.comboBox_2 = QComboBox(self.frame_6)
        self.comboBox_2.setObjectName(u"comboBox_2")

        self.horizontalLayout_5.addWidget(self.comboBox_2)


        self.verticalLayout_3.addLayout(self.horizontalLayout_5)


        self.verticalLayout_5.addWidget(self.frame_6)

        self.horizontalLayout = QHBoxLayout()
        self.horizontalLayout.setSpacing(6)
        self.horizontalLayout.setObjectName(u"horizontalLayout")
        self.horizontalLayout.setContentsMargins(-1, 0, -1, -1)
        self.pushPlot = QPushButton(Form)
        self.pushPlot.setObjectName(u"pushPlot")

        self.horizontalLayout.addWidget(self.pushPlot)

        self.horizontalSpacer = QSpacerItem(40, 20, QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Minimum)

        self.horizontalLayout.addItem(self.horizontalSpacer)

        self.pushClose = QPushButton(Form)
        self.pushClose.setObjectName(u"pushClose")

        self.horizontalLayout.addWidget(self.pushClose)


        self.verticalLayout_5.addLayout(self.horizontalLayout)


        self.retranslateUi(Form)

        QMetaObject.connectSlotsByName(Form)
    # setupUi

    def retranslateUi(self, Form):
        Form.setWindowTitle(QCoreApplication.translate("Form", u"debyetools - [E(V)]", None))
        self.label_3.setText(QCoreApplication.translate("Form", u"E(V):", None))
        self.EvVText_2.setPlainText("")
        self.radioButton_2.setText(QCoreApplication.translate("Form", u"eV and A^3 (per at)", None))
        self.radioButton_4.setText(QCoreApplication.translate("Form", u"J and m^3 (per mol-at)", None))
        self.label_7.setText(QCoreApplication.translate("Form", u"units:", None))
        self.pushloadEvV.setText(QCoreApplication.translate("Form", u"load E(V) ...", None))
        self.label_8.setText(QCoreApplication.translate("Form", u"EOS params:", None))
        self.lineEdit_3.setText("")
        self.pushButton_2.setText(QCoreApplication.translate("Form", u"fit", None))
        self.pushPlot.setText(QCoreApplication.translate("Form", u"plot E(V)", None))
        self.pushClose.setText(QCoreApplication.translate("Form", u"Save and Close", None))
    # retranslateUi




import sys
from PySide6.QtWidgets import QApplication

from debyetools.tpropsgui.start_window import StartWindow


def dtgui():
    """
    Function that calls the mainWindow class from  debyetools.tpropsgui.startwindow.
    """
    app = QApplication(sys.argv)
    widget = StartWindow()
    widget.app = app
    widget.show()
    sys.exit(app.exec())




